CommandTemplateBase class abstract

Inheritance
Implementers

Constructors

CommandTemplateBase(String cliTitle, ConsolePrinter consolePrinter, {bool allowIgnoreOptions = true})

Properties

aliases → List<String>
Alternate names for this command.
no setterinherited
argIgnore → List<String>?
no setter
argParser → ArgParser
The argument parser for this command.
no setterinherited
argRegExp → List<String>?
no setter
argResults → ArgResults?
The parsed argument results for this command.
no setterinherited
category → String
The command's category.
no setterinherited
cliTitle → String
finalinherited
consolePrinter → ConsolePrinter
finalinherited
description → String
A description of this command, included in usage.
no setterinherited
globalResults → ArgResults?
The parsed global argument results.
no setterinherited
hasError ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
Whether or not this command should be hidden from help listings.
no setterinherited
invocation → String
A single-line template for how to invoke this command (e.g. "pub get package").
no setterinherited
name → String
The name of this command.
no setterinherited
parent → Command<bool>?
The command's parent command, if this is a subcommand.
no setterinherited
runner → CommandRunner<bool>?
The command runner for this command.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subcommands → Map<String, Command<bool>>
An unmodifiable view of all sublevel commands of this command.
no setterinherited
suggestionAliases → List<String>
Alternate non-functional names for this command.
no setterinherited
summary → String
A short description of this command, included in parent's CommandRunner.usage.
no setterinherited
takesArguments → bool
Whether or not this command takes positional arguments in addition to options.
no setterinherited
usage → String
Generates a string displaying usage information for this command.
no setterinherited
usageFooter → String?
An optional footer for usage.
no setterinherited

Methods

addSubcommand(Command<bool> command) → void
Adds Command as a subcommand of this.
inherited
loadTemplate(String templatePath, {List<String>? ignorePath, List<Pattern>? ignoreRegexp}) → Future<Template>
log(String ns, String message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseRegExp() → List<RegExp>
printToConsole(Object? o) → void
inherited
printUsage() → void
Prints the usage information for this command.
inherited
readFile(String filePath) → String
inherited
run() → FutureOr<bool>?
Runs this command.
inherited
showError(String message) → void
inherited
showErrorOptionNotProvided(String option) → void
inherited
showTemplateInfos(Template template) → void
toString() → String
A string representation of this object.
inherited
usageException(String message) → Never
Throws a UsageException with message.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited